@@ -1,24 +1,25 @@
 # portlets imports
 import portlets.utils
 
+
 class PortletsBase(object):
     """Mixin class to make objects portlets aware.
     """
     def get_portlets(self, slot):
         """Returns True if the passed slot is blocked. Otherwise False.
-    
+
         **Parameters:**
-        
+
             slot
-                The slot for which the blocking is tested. Must be a Slot 
+                The slot for which the blocking is tested. Must be a Slot
                 instance.
         """
-        return portlets.utils.get_portlets(self, slot)
-        
+        return slot.get_portlets(self)
+
     def get_slots(self):
         """Returns all slots with all assigned portlets.
         """
-        return portlets.utils.is_blocked(self)
+        return portlets.utils.get_slots(self)
 
     def has_portlets(self, slot):
         """Returns True if the ther are portlets for the passed slot.
@@ -28,20 +29,20 @@ class PortletsBase(object):
             slot
                 The slot which is tested. Must be a Slot instance.
         """
-        return portlets.utils.has_portlets(self, slot)
-        
+        return slot.has_portlets(self)
+
     def is_blocked(self, slot):
         """Returns True if the passed slot is blocked. Otherwise False.
-    
+
         **Parameters:**
-            
+
             slot
-                The slot for which the blocking is tested. Must be a Slot 
+                The slot for which the blocking is tested. Must be a Slot
                 instance.
         """
-        return portlets.utils.is_blocked(self, slot)
+        return slot.is_blocked(self)
 
     def get_parent_for_portlets(self):
         """Returns the parent from which portlets are inherited.
         """
-        return None
\ No newline at end of file
+        return None
