@@ -4,10 +4,13 @@ from django.db import models
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 
+# portlets imports
 from portlets.models import Portlet
 
+
 class TextPortlet(Portlet):
-    """A simple portlet to display some text.
+    """
+    A simple portlet to display some text.
     """
     text = models.TextField(_(u"Text"), blank=True)
 
@@ -18,8 +21,8 @@ class TextPortlet(Portlet):
         """Renders the portlet as html.
         """
         return render_to_string("portlets/text_portlet.html", {
-            "title" : self.title,
-            "text" : self.text
+            "title": self.title,
+            "text": self.text
         })
 
     def form(self, **kwargs):
@@ -27,11 +30,10 @@ class TextPortlet(Portlet):
         """
         return TextPortletForm(instance=self, **kwargs)
 
+
 class TextPortletForm(forms.ModelForm):
-    """Form for the TextPortlet.
+    """
+    Form for the TextPortlet.
     """
     class Meta:
         model = TextPortlet
-        
-from portlets.utils import register_portlet
-register_portlet(TextPortlet, "TextPortlet")
